diff src/window.c @ 16650:06fd0eaada01 v8.1.1327

patch 8.1.1327: unnecessary scroll after horizontal split commit https://github.com/vim/vim/commit/a9b2535f44f3265940a18d08520a9ad4ef7bda82 Author: Bram Moolenaar <Bram@vim.org> Date: Sun May 12 14:25:30 2019 +0200 patch 8.1.1327: unnecessary scroll after horizontal split Problem: Unnecessary scroll after horizontal split. Solution: Don't adjust to fraction if all the text fits in the window. (Martin Kunev, closes #4367)
author Bram Moolenaar <Bram@vim.org>
date Sun, 12 May 2019 14:30:08 +0200
parents 8cc31b1b1d23
children 4e3c4e8e465c
line wrap: on
line diff
--- a/src/window.c
+++ b/src/window.c
@@ -5827,9 +5827,13 @@ scroll_to_fraction(win_T *wp, int prev_h
     int		sline, line_size;
     int		height = wp->w_height;
 
-    // Don't change w_topline when height is zero.  Don't set w_topline when
-    // 'scrollbind' is set and this isn't the current window.
-    if (height > 0 && (!wp->w_p_scb || wp == curwin))
+    // Don't change w_topline in any of these cases:
+    // - window height is 0
+    // - 'scrollbind' is set and this isn't the current window
+    // - window height is sufficient to display the whole buffer
+    if (height > 0
+        && (!wp->w_p_scb || wp == curwin)
+        && (height < wp->w_buffer->b_ml.ml_line_count))
     {
 	/*
 	 * Find a value for w_topline that shows the cursor at the same